const express = require("express");
const cors = require("cors");
const bodyParser = require("body-parser");

const mongoose = require("mongoose");

const dotenv = require("dotenv");
dotenv.config();

const app = express();
// parsing request of content-type as application/json
app.use(bodyParser.json());
app.use(
  cors({
    origin: "*" // helps to receive a request from any domain
  })
);

// import routes
const employeeRoutes = require("./routes/employees");
app.use("/api/employees", employeeRoutes);

// mongodb ui
const mongogui_port = 10091; // fix me - read the port dynamically.
// connect to db
const database_name = "employeedb";
const database_host = "localhost";
const database_port = 27017; // fix me - change mongodb port number.
const connection_string =
  "mongodb://" + database_host + ":" + database_port + "/" + database_name;
mongoose
  .connect(connection_string, {
    useNewUrlParser: true,
    useUnifiedTopology: true
  })
  .then(() => {
    console.log(
      `Connected to ${database_name} on ${database_port}. Mongodb ui available on port ${mongogui_port}.`
    );
  })
  .catch((err) => {
    console.log("Error while connecting to %s", database_name, err);
  });

// start app
const app_port = process.env.port || 3100;
app.listen(app_port, () => {
  console.log("Server started on port %s", app_port);
});
